/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { IFluidCodeDetails, IFluidCodeResolver, IResolvedFluidCodeDetails } from "@fluidframework/container-definitions";
/**
 * This code resolver works against cdns that support semantic verioning in the url path of the format:
 * `cdn_base/@package_scope?/package_name@package_version`
 *
 * The `@package_scope?` is optional, and only needed it the package has a scope.
 * The `package_version` can be an npm style semantic version.
 *
 * The `cdn_base` is provided in the config of the Fluid code details, as either a global `config.cdn` property, or
 * a per scope cdn, `config["@package_scope:cdn"]`. A scope specific cdn base will take precedence over
 * the global cdn.
 */
export declare class SemVerCdnCodeResolver implements IFluidCodeResolver {
    private readonly fluidPackageCache;
    resolveCodeDetails(details: IFluidCodeDetails): Promise<IResolvedFluidCodeDetails>;
}
//# sourceMappingURL=semVerCdnCodeResolver.d.ts.map